// The MIT License (MIT)
//
// Copyright (c) 2015 Alexander Grebenyuk (github.com/kean).
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

#import "DFImageProcessing.h"
#import "DFImageRequestOptions.h"
#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

/*! NSNumber with float value that specifies a normalized image corner radius, where 0.5 is a corner radius that is half of the minimum image side. Should be put into DFImageRequestOptions userInfo dictionary.
 */
extern NSString *DFImageProcessingCornerRadiusKey;

/*! The DFImageProcessor implements image decompression, scaling, cropping and more.
 */
@interface DFImageProcessor : NSObject <DFImageProcessing>

/*! Returns decompressed image with a given image.
 */
+ (UIImage *)decompressedWithImage:(UIImage *)image;

/*! Returns decompressed image with a given image.
 @param targetSize Image target size in pixels.
 */
+ (UIImage *)decompressedImageWithImage:(UIImage *)image targetSize:(CGSize)targetSize contentMode:(DFImageContentMode)contentMode;

/*! Returns scaled decompressed image with a given image.
 */
+ (UIImage *)decompressedWithImage:(UIImage *)image scale:(CGFloat)scale;

/*! Returns image cropped to a given normalized crop rect.
 */
+ (UIImage *)croppedImageWithImage:(UIImage *)image normalizedCropRect:(CGRect)cropRect;

/*! Returns image by drawing rounded corners.
 @param cornerRadius corner radius in points.
 */
+ (UIImage *)imageWithImage:(UIImage *)image cornerRadius:(CGFloat)cornerRadius;

@end
